"""
Usage:
    agw cursor
    agw jiggle
    agw screenshot (--capture | --find)

Options:
    -h --help       Display this screen.
    --version       Display application version.
"""
import docopt
from .cursor import position as cursor
from .jiggler import jiggle
from .screen import capture, find


def main():
    args = docopt.docopt(__doc__)

    if args.get("cursor") is True:
        cursor()
    elif args.get("jiggle") is True:
        jiggle()
    elif args.get("screenshot") is True and args.get("--capture"):
        capture()
    elif args.get("screenshot") is True and args.get("--find"):
        find()



import pyautogui as ag
from pyscreeze import ImageNotFoundException


def locate_image(image, region=None):
    try:
        return ag.locateOnScreen(image, region=region)
    except ImageNotFoundException:
        return None


def image_located(image, region=None, note=None, action=None):

    result = locate_image(image, region=region)

    if result and note:
        print(note)

    if result and action:
        action()

    return result
